==> clutter-1.22.4.tgz: include/clutter-1.0/clutter/clutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CLUTTER_ENUM_TYPES_H__
#define __CLUTTER_ENUM_TYPES_H__

#if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
#error "Only <clutter/clutter.h> can be included directly."
#endif

#include <clutter/clutter-types.h>

G_BEGIN_DECLS

/* enumerations from "./clutter-enums.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAVITY (clutter_gravity_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_rotate_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_AXIS (clutter_rotate_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_rotate_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_DIRECTION (clutter_rotate_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_request_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REQUEST_MODE (clutter_request_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_animation_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ANIMATION_MODE (clutter_animation_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_font_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FONT_FLAGS (clutter_font_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_text_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXT_DIRECTION (clutter_text_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_shader_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_TYPE (clutter_shader_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_modifier_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_MODIFIER_TYPE (clutter_modifier_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_actor_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_FLAGS (clutter_actor_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_offscreen_redirect_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_OFFSCREEN_REDIRECT (clutter_offscreen_redirect_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_allocation_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ALLOCATION_FLAGS (clutter_allocation_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_align_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ALIGN_AXIS (clutter_align_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_interpolation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INTERPOLATION (clutter_interpolation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_bin_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIN_ALIGNMENT (clutter_bin_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_bind_coordinate_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIND_COORDINATE (clutter_bind_coordinate_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_effect_paint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EFFECT_PAINT_FLAGS (clutter_effect_paint_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_box_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BOX_ALIGNMENT (clutter_box_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_long_press_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_LONG_PRESS_STATE (clutter_long_press_state_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_static_color_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STATIC_COLOR (clutter_static_color_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_drag_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_DRAG_AXIS (clutter_drag_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_event_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_FLAGS (clutter_event_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_event_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_TYPE (clutter_event_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scroll_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_DIRECTION (clutter_scroll_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_stage_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STAGE_STATE (clutter_stage_state_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_feature_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FEATURE_FLAGS (clutter_feature_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_flow_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FLOW_ORIENTATION (clutter_flow_orientation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_device_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_TYPE (clutter_input_device_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_MODE (clutter_input_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_AXIS (clutter_input_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_snap_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SNAP_EDGE (clutter_snap_edge_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_pick_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PICK_MODE (clutter_pick_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_swipe_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SWIPE_DIRECTION (clutter_swipe_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_pan_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PAN_AXIS (clutter_pan_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_table_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TABLE_ALIGNMENT (clutter_table_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_FLAGS (clutter_texture_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_quality_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_QUALITY (clutter_texture_quality_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_timeline_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TIMELINE_DIRECTION (clutter_timeline_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_unit_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_UNIT_TYPE (clutter_unit_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_path_node_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PATH_NODE_TYPE (clutter_path_node_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_actor_align_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_ALIGN (clutter_actor_align_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_repaint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REPAINT_FLAGS (clutter_repaint_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_content_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_GRAVITY (clutter_content_gravity_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scaling_filter_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCALING_FILTER (clutter_scaling_filter_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ORIENTATION (clutter_orientation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scroll_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_MODE (clutter_scroll_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_grid_position_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRID_POSITION (clutter_grid_position_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_content_repeat_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_REPEAT (clutter_content_repeat_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_step_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STEP_MODE (clutter_step_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_zoom_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ZOOM_AXIS (clutter_zoom_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_gesture_trigger_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GESTURE_TRIGGER_EDGE (clutter_gesture_trigger_edge_get_type())

/* enumerations from "./clutter-image.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_image_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_IMAGE_ERROR (clutter_image_error_get_type())

/* enumerations from "./clutter-main.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_init_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INIT_ERROR (clutter_init_error_get_type())

/* enumerations from "./clutter-script.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_script_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCRIPT_ERROR (clutter_script_error_get_type())

/* enumerations from "./clutter-texture.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_ERROR (clutter_texture_error_get_type())

/* enumerations from "./deprecated/clutter-shader.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_shader_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_ERROR (clutter_shader_error_get_type())

/* enumerations from "./x11/clutter-x11.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_x11_filter_return_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_X11_FILTER_RETURN (clutter_x11_filter_return_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_x11_xinput_event_types_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_X11_XINPUT_EVENT_TYPES (clutter_x11_xinput_event_types_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */

==> clutter-1.24.2.tgz: include/clutter-1.0/clutter/clutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CLUTTER_ENUM_TYPES_H__
#define __CLUTTER_ENUM_TYPES_H__

#if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
#error "Only <clutter/clutter.h> can be included directly."
#endif

#include <clutter/clutter-types.h>

G_BEGIN_DECLS

/* enumerations from "./clutter-enums.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAVITY (clutter_gravity_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_rotate_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_AXIS (clutter_rotate_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_rotate_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_DIRECTION (clutter_rotate_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_request_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REQUEST_MODE (clutter_request_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_animation_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ANIMATION_MODE (clutter_animation_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_font_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FONT_FLAGS (clutter_font_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_text_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXT_DIRECTION (clutter_text_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_shader_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_TYPE (clutter_shader_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_modifier_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_MODIFIER_TYPE (clutter_modifier_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_actor_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_FLAGS (clutter_actor_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_offscreen_redirect_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_OFFSCREEN_REDIRECT (clutter_offscreen_redirect_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_allocation_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ALLOCATION_FLAGS (clutter_allocation_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_align_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ALIGN_AXIS (clutter_align_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_interpolation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INTERPOLATION (clutter_interpolation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_bin_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIN_ALIGNMENT (clutter_bin_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_bind_coordinate_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIND_COORDINATE (clutter_bind_coordinate_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_effect_paint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EFFECT_PAINT_FLAGS (clutter_effect_paint_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_box_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BOX_ALIGNMENT (clutter_box_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_long_press_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_LONG_PRESS_STATE (clutter_long_press_state_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_static_color_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STATIC_COLOR (clutter_static_color_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_drag_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_DRAG_AXIS (clutter_drag_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_event_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_FLAGS (clutter_event_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_event_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_TYPE (clutter_event_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scroll_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_DIRECTION (clutter_scroll_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_stage_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STAGE_STATE (clutter_stage_state_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_feature_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FEATURE_FLAGS (clutter_feature_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_flow_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FLOW_ORIENTATION (clutter_flow_orientation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_device_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_TYPE (clutter_input_device_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_MODE (clutter_input_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_input_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_AXIS (clutter_input_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_snap_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SNAP_EDGE (clutter_snap_edge_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_pick_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PICK_MODE (clutter_pick_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_swipe_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SWIPE_DIRECTION (clutter_swipe_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_pan_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PAN_AXIS (clutter_pan_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_table_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TABLE_ALIGNMENT (clutter_table_alignment_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_FLAGS (clutter_texture_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_quality_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_QUALITY (clutter_texture_quality_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_timeline_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TIMELINE_DIRECTION (clutter_timeline_direction_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_unit_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_UNIT_TYPE (clutter_unit_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_path_node_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PATH_NODE_TYPE (clutter_path_node_type_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_actor_align_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_ALIGN (clutter_actor_align_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_repaint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REPAINT_FLAGS (clutter_repaint_flags_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_content_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_GRAVITY (clutter_content_gravity_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scaling_filter_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCALING_FILTER (clutter_scaling_filter_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ORIENTATION (clutter_orientation_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_scroll_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_MODE (clutter_scroll_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_grid_position_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRID_POSITION (clutter_grid_position_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_content_repeat_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_REPEAT (clutter_content_repeat_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_step_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STEP_MODE (clutter_step_mode_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_zoom_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ZOOM_AXIS (clutter_zoom_axis_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_gesture_trigger_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GESTURE_TRIGGER_EDGE (clutter_gesture_trigger_edge_get_type())

CLUTTER_AVAILABLE_IN_ALL GType clutter_touchpad_gesture_phase_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TOUCHPAD_GESTURE_PHASE (clutter_touchpad_gesture_phase_get_type())

/* enumerations from "./clutter-image.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_image_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_IMAGE_ERROR (clutter_image_error_get_type())

/* enumerations from "./clutter-main.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_init_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INIT_ERROR (clutter_init_error_get_type())

/* enumerations from "./clutter-script.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_script_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCRIPT_ERROR (clutter_script_error_get_type())

/* enumerations from "./clutter-texture.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_texture_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_ERROR (clutter_texture_error_get_type())

/* enumerations from "./deprecated/clutter-shader.h" */
CLUTTER_AVAILABLE_IN_ALL GType clutter_shader_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_ERROR (clutter_shader_error_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */
